# This is a dedicated spec file for building jglobus for EPEL 6
# Instead of using maven - which is not available on RHEL/EPEL - ant
# is used for building. The ant build files were created using the
# maven ant plugin

Name:		jglobus
Version:	2.1.0
Release:	7%{?dist}
Summary:	Globus Java client libraries

#		Everything is Apache 2.0 except for one file that is MIT:
#		ssl-proxies/src/main/java/org/globus/tools/GridCertRequest.java
License:	ASL 2.0 and MIT
URL:		http://github.com/%{name}/
Source0:	http://github.com/%{name}/JGlobus/archive/JGlobus-Release-%{version}.tar.gz
#		Build with ant on old distributions
Source1:	%{name}-ant-%{version}.tar.gz
#		DERObjectIdentifier is obsolete
#		https://github.com/jglobus/JGlobus/pull/149
Patch0:		%{name}-DERObjectIdentifier-is-obsolete.patch
#		Don't force SSLv3 in myproxy, allow TLS
#		Backport from git (trunk)
Patch1:		%{name}-dont-force-SSLv3.patch
#		Relax proxy validation to be RFC-3820 compliant
#		https://github.com/jglobus/JGlobus/issues/160
#		https://github.com/jglobus/JGlobus/pull/165
Patch2:		%{name}-key-usage.patch
#		Fix javadoc
#		https://github.com/jglobus/JGlobus/pull/162
Patch3:		%{name}-javadoc.patch
#		Do not accumulate matches in
#		GlobusPathMatchingResourcePatternResolver
#		https://github.com/jglobus/JGlobus/pull/157
Patch4:		%{name}-do-not-accumulate-matches-in-GlobusPathMatchingResou.patch
#		Compatibility with clients that request minimum TLS version 1.2
#		https://github.com/jglobus/JGlobus/pull/166
Patch5:		%{name}-do-not-force-SSLv3-TLSv1-allow-TLSv1.1-TLSv1.2.patch
#		Remove synchronization on CRL in CRLChecker
#		Drop workaround for race condition in BouncyCastle < 1.46
#		Reduced lock contention leads to higher request throughput
#		Backport from git (trunk and 2.1 branch)
Patch6:		%{name}-remove-synchronization-on-CRL-in-CRLChecker.patch
#		Fix "no key" error for PKCS#8 encoded keys
#		https://github.com/jglobus/JGlobus/issues/118
#		https://github.com/jglobus/JGlobus/issues/146
#		https://github.com/jglobus/JGlobus/pull/164
Patch7:		%{name}-support-PKCS8-key-format.patch
#		Only allow TLSv1 and TLSv1.2 (not TLSv1.1)
#		https://github.com/jglobus/JGlobus/pull/166
Patch8:		%{name}-only-allow-TLSv1-and-TLSv1.2-not-TLSv1.1.patch
#		Remove unused FORCE_SSLV3_AND_CONSTRAIN_CIPHERSUITES_FOR_GRAM
#		https://github.com/jglobus/JGlobus/pull/166
Patch9:		%{name}-remove-unused-FORCE_SSLV3_AND_CONSTRAIN_CIPHERSUITES.patch
#		Adapt to changes in bouncycastle 1.61
#		https://github.com/jglobus/JGlobus/pull/168
Patch10:	%{name}-adapt-to-changes-in-PrivateKeyInfo-class.patch

BuildArch:	noarch
#		There is no jakarta-commons-io for ppc64 in EPEL6
ExcludeArch:	ppc64

BuildRequires:	jpackage-utils
BuildRequires:	java-devel
BuildRequires:	ant
BuildRequires:	jakarta-commons-codec
BuildRequires:	jakarta-commons-io
BuildRequires:	jakarta-commons-logging
BuildRequires:	bouncycastle1.58
BuildRequires:	log4j
BuildRequires:	tomcat-lib
BuildRequires:	axis
BuildRequires:	servlet

%description
%{name} is a collection of Java client libraries for Globus Toolkit security,
GRAM, GridFTP and MyProxy.

%package parent
Summary:	Globus Java - parent pom file
License:	ASL 2.0
Requires:	jpackage-utils
Requires:	java

%description parent
Globus Java libraries parent maven pom file

%package ssl-proxies
Summary:	Globus Java - SSL and proxy certificate support
License:	ASL 2.0 and MIT
Requires:	jpackage-utils
Requires:	java
Requires:	jakarta-commons-codec
Requires:	jakarta-commons-io
Requires:	jakarta-commons-logging
Requires:	bouncycastle1.58
Requires:	log4j

%description ssl-proxies
Globus Java library with SSL and proxy certificate support

%package jsse
Summary:	Globus Java - SSL support
License:	ASL 2.0
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-ssl-proxies = %{version}-%{release}

%description jsse
Globus Java library with SSL support

%package gss
Summary:	Globus Java - GSS-API implementation for SSL with proxies
License:	ASL 2.0
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-jsse = %{version}-%{release}

%description gss
Globus Java GSS-API implementation for SSL with proxies

%package gram
Summary:	Globus Java - Grid Resource Allocation and Management (GRAM)
License:	ASL 2.0
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-gss = %{version}-%{release}

%description gram
Globus Java library with GRAM support

%package gridftp
Summary:	Globus Java - GridFTP
License:	ASL 2.0
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-gss = %{version}-%{release}

%description gridftp
Globus Java library with GridFTP support

%package ssl-proxies-tomcat
Summary:	Globus Java - SSL and proxy certificate support for Tomcat
License:	ASL 2.0
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-jsse = %{version}-%{release}
Requires:	tomcat-lib

%description ssl-proxies-tomcat
Globus Java library with SSL and proxy certificate support for Tomcat

%package io
Summary:	Globus Java - IO
License:	ASL 2.0
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-gram = %{version}-%{release}
Requires:	%{name}-gridftp = %{version}-%{release}

%description io
Globus Java library with IO utilities

%package myproxy
Summary:	Globus Java - MyProxy
License:	ASL 2.0
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-gss = %{version}-%{release}

%description myproxy
Globus Java library with MyProxy support

%package axisg
Summary:	Globus Java - Apache AXIS support
License:	ASL 2.0
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-gss = %{version}-%{release}
Requires:	axis
Requires:	servlet

%description axisg
Globus Java library with Apache AXIS support

%package javadoc
Summary:	Javadoc for %{name}
License:	ASL 2.0 and MIT
Requires:	jpackage-utils

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -a 1 -n JGlobus-JGlobus-Release-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1

%build
# Many tests requires network connections and a valid proxy certificate
export CLASSPATH=$(build-classpath bcprov-1.58 log4j commons-codec commons-httpclient commons-io commons-logging tomcat/catalina tomcat/tomcat-coyote tomcat/tomcat-util.jar axis/axis axis/jaxrpc servlet):ssl-proxies/target/ssl-proxies-%{version}.jar:jsse/target/jsse-%{version}.jar:gss/target/gss-%{version}.jar:gram/target/gram-%{version}.jar:gridftp/target/gridftp-%{version}.jar
ant -Dmaven.test.skip=true package javadoc

%install
mkdir -p %{buildroot}%{_javadir}/%{name}

install -p -m 644 ssl-proxies/target/ssl-proxies-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/ssl-proxies.jar
install -p -m 644 jsse/target/jsse-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/jsse.jar
install -p -m 644 gss/target/gss-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/gss.jar
install -p -m 644 gram/target/gram-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/gram.jar
install -p -m 644 gridftp/target/gridftp-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/gridftp.jar
install -p -m 644 ssl-proxies-tomcat/target/ssl-proxies-tomcat-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/ssl-proxies-tomcat.jar
install -p -m 644 io/target/io-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/io.jar
install -p -m 644 myproxy/target/myproxy-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/myproxy.jar
install -p -m 644 axis/target/axisg-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/axisg.jar

mkdir -p %{buildroot}%{_javadocdir}/%{name}

cp -pr ssl-proxies/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/ssl-proxies
cp -pr jsse/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/jsse
cp -pr gss/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/gss
cp -pr gram/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/gram
cp -pr gridftp/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/gridftp
cp -pr ssl-proxies-tomcat/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/ssl-proxies-tomcat
cp -pr io/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/io
cp -pr myproxy/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/myproxy
cp -pr axis/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/axisg

mkdir -p %{buildroot}%{_mavenpomdir}

install -p -m 644 pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-parent.pom
%add_to_maven_depmap org.jglobus parent %{version} JPP/%{name} parent
mv %{buildroot}%{_mavendepmapfragdir}/%{name} \
   %{buildroot}%{_mavendepmapfragdir}/%{name}-parent

install -p -m 644 ssl-proxies/pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-ssl-proxies.pom
%add_to_maven_depmap org.jglobus ssl-proxies %{version} JPP/%{name} ssl-proxies
mv %{buildroot}%{_mavendepmapfragdir}/%{name} \
   %{buildroot}%{_mavendepmapfragdir}/%{name}-ssl-proxies

install -p -m 644 jsse/pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-jsse.pom
%add_to_maven_depmap org.jglobus jsse %{version} JPP/%{name} jsse
mv %{buildroot}%{_mavendepmapfragdir}/%{name} \
   %{buildroot}%{_mavendepmapfragdir}/%{name}-jsse

install -p -m 644 gss/pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-gss.pom
%add_to_maven_depmap org.jglobus gss %{version} JPP/%{name} gss
mv %{buildroot}%{_mavendepmapfragdir}/%{name} \
   %{buildroot}%{_mavendepmapfragdir}/%{name}-gss

install -p -m 644 gram/pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-gram.pom
%add_to_maven_depmap org.jglobus gram %{version} JPP/%{name} gram
mv %{buildroot}%{_mavendepmapfragdir}/%{name} \
   %{buildroot}%{_mavendepmapfragdir}/%{name}-gram

install -p -m 644 gridftp/pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-gridftp.pom
%add_to_maven_depmap org.jglobus gridftp %{version} JPP/%{name} gridftp
mv %{buildroot}%{_mavendepmapfragdir}/%{name} \
   %{buildroot}%{_mavendepmapfragdir}/%{name}-gridftp

install -p -m 644 ssl-proxies-tomcat/pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-ssl-proxies-tomcat.pom
%add_to_maven_depmap org.jglobus ssl-proxies-tomcat %{version} JPP/%{name} ssl-proxies-tomcat
mv %{buildroot}%{_mavendepmapfragdir}/%{name} \
   %{buildroot}%{_mavendepmapfragdir}/%{name}-ssl-proxies-tomcat

install -p -m 644 io/pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-io.pom
%add_to_maven_depmap org.jglobus io %{version} JPP/%{name} io
mv %{buildroot}%{_mavendepmapfragdir}/%{name} \
   %{buildroot}%{_mavendepmapfragdir}/%{name}-io

install -p -m 644 myproxy/pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-myproxy.pom
%add_to_maven_depmap org.jglobus myproxy %{version} JPP/%{name} myproxy
mv %{buildroot}%{_mavendepmapfragdir}/%{name} \
   %{buildroot}%{_mavendepmapfragdir}/%{name}-myproxy

install -p -m 644 axis/pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-axisg.pom
%add_to_maven_depmap org.jglobus axisg %{version} JPP/%{name} axisg
mv %{buildroot}%{_mavendepmapfragdir}/%{name} \
   %{buildroot}%{_mavendepmapfragdir}/%{name}-axisg

%post parent
%update_maven_depmap
%postun parent
%update_maven_depmap

%post ssl-proxies
%update_maven_depmap
%postun ssl-proxies
%update_maven_depmap

%post jsse
%update_maven_depmap
%postun jsse
%update_maven_depmap

%post gss
%update_maven_depmap
%postun gss
%update_maven_depmap

%post gram
%update_maven_depmap
%postun gram
%update_maven_depmap

%post gridftp
%update_maven_depmap
%postun gridftp
%update_maven_depmap

%post ssl-proxies-tomcat
%update_maven_depmap
%postun ssl-proxies-tomcat
%update_maven_depmap

%post io
%update_maven_depmap
%postun io
%update_maven_depmap

%post myproxy
%update_maven_depmap
%postun myproxy
%update_maven_depmap

%post axisg
%update_maven_depmap
%postun axisg
%update_maven_depmap

%files parent
%{_mavenpomdir}/JPP.%{name}-parent.pom
%{_mavendepmapfragdir}/%{name}-parent
%doc LICENSE

%files ssl-proxies
%dir %{_javadir}/%{name}
%{_javadir}/%{name}/ssl-proxies.jar
%{_mavenpomdir}/JPP.%{name}-ssl-proxies.pom
%config(noreplace) %{_mavendepmapfragdir}/%{name}-ssl-proxies
%doc LICENSE README.textile

%files jsse
%{_javadir}/%{name}/jsse.jar
%{_mavenpomdir}/JPP.%{name}-jsse.pom
%config(noreplace) %{_mavendepmapfragdir}/%{name}-jsse

%files gss
%{_javadir}/%{name}/gss.jar
%{_mavenpomdir}/JPP.%{name}-gss.pom
%config(noreplace) %{_mavendepmapfragdir}/%{name}-gss

%files gram
%{_javadir}/%{name}/gram.jar
%{_mavenpomdir}/JPP.%{name}-gram.pom
%config(noreplace) %{_mavendepmapfragdir}/%{name}-gram

%files gridftp
%{_javadir}/%{name}/gridftp.jar
%{_mavenpomdir}/JPP.%{name}-gridftp.pom
%config(noreplace) %{_mavendepmapfragdir}/%{name}-gridftp

%files ssl-proxies-tomcat
%{_javadir}/%{name}/ssl-proxies-tomcat.jar
%{_mavenpomdir}/JPP.%{name}-ssl-proxies-tomcat.pom
%config(noreplace) %{_mavendepmapfragdir}/%{name}-ssl-proxies-tomcat

%files io
%{_javadir}/%{name}/io.jar
%{_mavenpomdir}/JPP.%{name}-io.pom
%config(noreplace) %{_mavendepmapfragdir}/%{name}-io

%files myproxy
%{_javadir}/%{name}/myproxy.jar
%{_mavenpomdir}/JPP.%{name}-myproxy.pom
%config(noreplace) %{_mavendepmapfragdir}/%{name}-myproxy

%files axisg
%{_javadir}/%{name}/axisg.jar
%{_mavenpomdir}/JPP.%{name}-axisg.pom
%config(noreplace) %{_mavendepmapfragdir}/%{name}-axisg
%doc axis/src/main/java/org/globus/axis/example/README.txt

%files javadoc
%doc %{_javadocdir}/%{name}

%changelog
* Sun Feb 10 2019 Mattias Ellert <mattias.ellert@physics.uu.se> - 2.1.0-7
- Only allow TLSv1 and TLSv1.2 (not TLSv1.1)
- Remove unused FORCE_SSLV3_AND_CONSTRAIN_CIPHERSUITES_FOR_GRAM
- Adapt to changes in bouncycastle 1.61

* Tue Oct 30 2018 Mattias Ellert <mattias.ellert@physics.uu.se> - 2.1.0-6
- Apply patches from OSG/WLCG

* Wed Feb 07 2018 Mattias Ellert <mattias.ellert@physics.uu.se> - 2.1.0-5
- Build against bouncycastle1.58

* Sat Jan 06 2018 Mattias Ellert <mattias.ellert@physics.uu.se> - 2.1.0-4
- Remove backport to bouncycastle 1.46

* Mon Jul 03 2017 Mattias Ellert <mattias.ellert@physics.uu.se> - 2.1.0-3
- Relax proxy validation to be RFC-3820 compliant
- Fix javadoc

* Thu Jun 18 2015 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.1.0-2
- Do not force the use of SSLv3 in myproxy

* Wed Oct 01 2014 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.1.0-1
- 2.1.0 final release
- Drop patches included upstream
- Install pom files

* Mon Nov 25 2013 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.6-2
- Fix source URL

* Wed Aug 14 2013 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.6-1
- 2.0.6 final release

* Tue Mar 26 2013 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.5-1
- 2.0.5 final release

* Tue Jan 29 2013 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.5-0.1.rc2
- 2.0.5 release candidate 2
- New jglobus-myproxy package
- New jglobus-axisg package

* Sat Oct 13 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-9.20121013git597e3ac
- Git snapshot

* Wed Oct 10 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-8.20121010git8eefd68
- Git snapshot
- Drop patches applied upstream

* Wed Oct 10 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-7.20121010git5286c6b
- Git snapshot
- Drop patches applied upstream

* Thu Sep 27 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-6
- Drop spring framework dependency (based on pull request in github)
- Allows building on EPEL

* Mon Aug 13 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-5
- Build the tomcat module

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri May 04 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-3
- Adapt to changes in automatic maven rpm dependency generation

* Mon Apr 23 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-2
- Add MIT license tag

* Fri Apr 13 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-1
- First packaging
